2.4. Loading publication files — machado 0.1.0 documentation

# 2.4. Loading publication files

## 2.4.1. Load publication

    python manage.py load_publication --file reference.bib

- Loading this file can be faster if you increase the number of threads (–cpu).

## 2.4.2. Remove publication

If, by any reason, you need to remove a publication you should use the command remove_publication. If you delete a publication, every record that depend on it will be deleted on cascade, with the exception of the Dbxref field that contains the DOI accession.

    python manage.py remove_publication --help